==> eslint-config-docs-1.1.1.tgz: package/index.js <==
module.exports = {
  extends: [
    "@mapbox/eslint-config-mapbox/react",
    "@mapbox/eslint-config-mapbox/import",
    "@mapbox/eslint-config-mapbox/promise",
    "@mapbox/eslint-config-mapbox/xss",
    "plugin:es/restrict-to-es5",
    "plugin:@mapbox/gl-wrapper/recommended",
    "prettier",
  ],
  parser: "babel-eslint",
  env: {
    browser: true,
  },
  parserOptions: {
    sourceType: "module",
    ecmaFeatures: {
      jsx: true,
    },
  },
  globals: {
    MapboxPageShell: true,
    analytics: true,
  },
  plugins: ["react", "es"],
  rules: {
    /* react */
    "react/jsx-uses-react": "error",
    "react/jsx-uses-vars": "error",
    "react/default-props-match-prop-types": "error",
    "react/no-unused-prop-types": "error",
    "react/no-deprecated": "off",
    "react/no-string-refs": "off",
    "react/no-access-state-in-setstate": "off",
    "react/jsx-boolean-value": "off",
    "react/prop-types": "error",
    "react/no-unused-state": "error",
    /* es overrides */
    "es/no-modules": "off",
    "es/no-block-scoped-variables": "off",
    "es/no-arrow-functions": "off",
    "es/no-classes": "off",
    "es/no-template-literals": "off",
    "es/no-property-shorthands": "off",
    "es/no-destructuring": "off",
    "es/no-default-parameters": "off",
    "es/no-rest-spread-properties": "off",
    "es/no-spread-elements": "off",
    "es/no-dynamic-import": "off",
    /* misc */
    "spaced-comment": "off",
    "prefer-const": "off",
    /* Batfish */
    "import/no-unresolved": ["error", { ignore: ["^@mapbox/batfish/data/"] }],
  },
  settings: {
    react: {
      version: "detect",
    },
  },
};

==> eslint-config-docs-1.2.0.tgz: package/index.js <==
module.exports = {
  extends: [
    "@mapbox/eslint-config-mapbox/react",
    "@mapbox/eslint-config-mapbox/import",
    "@mapbox/eslint-config-mapbox/promise",
    "@mapbox/eslint-config-mapbox/xss",
    "plugin:es/restrict-to-es5",
    "plugin:@mapbox/docs/recommended",
    "prettier",
  ],
  parser: "babel-eslint",
  env: {
    browser: true,
  },
  parserOptions: {
    sourceType: "module",
    ecmaFeatures: {
      jsx: true,
    },
  },
  globals: {
    MapboxPageShell: true,
    analytics: true,
  },
  plugins: ["react", "es"],
  rules: {
    /* react */
    "react/jsx-uses-react": "error",
    "react/jsx-uses-vars": "error",
    "react/default-props-match-prop-types": "error",
    "react/no-unused-prop-types": "error",
    "react/no-deprecated": "off",
    "react/no-string-refs": "off",
    "react/no-access-state-in-setstate": "off",
    "react/jsx-boolean-value": "off",
    "react/prop-types": "error",
    "react/no-unused-state": "error",
    /* es overrides */
    "es/no-modules": "off",
    "es/no-block-scoped-variables": "off",
    "es/no-arrow-functions": "off",
    "es/no-classes": "off",
    "es/no-template-literals": "off",
    "es/no-property-shorthands": "off",
    "es/no-destructuring": "off",
    "es/no-default-parameters": "off",
    "es/no-rest-spread-properties": "off",
    "es/no-spread-elements": "off",
    "es/no-dynamic-import": "off",
    /* misc */
    "spaced-comment": "off",
    "prefer-const": "off",
    /* Batfish */
    "import/no-unresolved": ["error", { ignore: ["^@mapbox/batfish/data/"] }],
  },
  settings: {
    react: {
      version: "detect",
    },
  },
};
